@@ -13,13 +13,15 @@
    Copyright 2022, HSPyLib team
 """
 
-from clitt.core.icons.font_awesome.nav_icons import NavIcons
-from clitt.core.tui.tui_component import TUIComponent
 from functools import cached_property
+from typing import List, Optional, TypeVar
+
 from hspylib.core.tools.commons import sysout
 from hspylib.modules.cli.keyboard import Keyboard
 from hspylib.modules.cli.vt100.vt_utils import erase_line, prepare_render, restore_cursor, screen_size
-from typing import List, Optional, TypeVar
+
+from clitt.core.icons.font_awesome.nav_icons import NavIcons
+from clitt.core.tui.tui_component import TUIComponent
 
 T = TypeVar("T")
 
@@ -71,6 +73,8 @@ class MenuSelect(TUIComponent):
             # Navigation input
             keypress = self._handle_keypress()
 
+        sysout("%MOD(0)%")
+
         return self.items[self.sel_index] if keypress == Keyboard.VK_ENTER else None
 
     def _render(self) -> None:
@@ -105,7 +109,7 @@ class MenuSelect(TUIComponent):
         return (
             f"%EOL%{self.prefs.navbar_color.placeholder}"
             f"[Enter] Select  [{self.NAV_ICONS}] "
-            f"Navigate  [Esc] Quit  [1..{kwargs['to']}] Goto: %NC%%EL0%%EOL%%EOL%"
+            f"Navigate  [Esc] Quit  [1..{kwargs['to']}] Goto: %NC%%EL0%"
         )
 
     def _handle_keypress(self) -> Keyboard:
